unemployrate: U.S. monthly civilian unemployment rate
Description
U.S. monthly civilian unemployment rate, seasonally adjusted and measured in percentage, from January 1948 to March 2004. The data set is available in Tsay (2005).format
unemployrate is a data frame with 675 observationssource
The data are obtained from the Bureau of Labor statistics, Department of Labor.References
Tsay, R.S. (2005) Analysis of Financial Time Series. Second ed. Wiley, Hoboken.Examples
Run this codedata(unemployrate)
plot.ts(unemployrate)
Run the code above in your browser using DataLab